package cn.com.ctop.toutiao.modules.tool.service;

import cn.com.ctop.common.module.entity.CtopOauthToken;
import com.alibaba.fastjson.JSONObject;

import java.util.List;
import java.util.Map;

public interface IByteDanceQueryToolService {

    //查询受众预估结果  https://ad.oceanengine.com/open_api/2/tools/estimate_audience/
    Map<String,Object> queryEstimateAudience(CtopOauthToken token, Long advertiserId, JSONObject requestBody);

    //查询应用信息  https://ad.oceanengine.com/open_api/2/tools/app_search/
    Map<String,Object> queryAppSearch(CtopOauthToken token,Long advertiserId,JSONObject requestBody);

    //建议日预算及预期成本  https://ad.oceanengine.com/open_api/2/tools/bid/suggest/
    Map<String,Object> queryBidSuggest(CtopOauthToken token,JSONObject requestBody);

    //查询广告质量度  https://ad.oceanengine.com/open_api/2/tools/ad_quality/get/
    Map<String,Object> queryAdQualityGet(CtopOauthToken token, Long advertiserId, List<Long> adIds);

    /**
     *  已经拉取到汇创后台
     */
    /*//获取行业列表  https://ad.oceanengine.com/open_api/2/tools/industry/get/
    Map<String,Object> queryIndustryGet(CtopOauthToken token);

    //获取地域列表  https://ad.oceanengine.com/open_api/2/tools/region/get/
    Map<String,Object> queryRegionGet(CtopOauthToken token);*/

    //查询广告主门店 https://ad.oceanengine.com/open_api/2/tools/advertiser_store/search/
    Map<String,Object> queryAdvertiserStoreSearch(CtopOauthToken token, Long advertiserId, String type,String page,String pageSize);

   /* //获取广告预览二维码  https://ad.oceanengine.com/open_api/2/tools/ad_preview/qrcode_get/
    Map<String,Object> queryAdPreviewCodeGet(CtopOauthToken token);

    //日志查询  可查询ad后台操作日志，默认查询最近7天的数据，最多查询跨度为半年。
    //https://ad.oceanengine.com/open_api/2/tools/log_search/
    Map<String,Object> queryLogSearch(CtopOauthToken token);*/

    //查询程序化创意包  https://ad.oceanengine.com/open_api/2/tools/procedural_package/get/
    Map<String,Object> queryProceduralPackageGet(CtopOauthToken token, Long advertiserId,JSONObject requestBody);

    //查询门店活动  https://ad.oceanengine.com/open_api/2/tools/advertiser_store/search_pack/
    Map<String,Object> queryAdvertiserStoreSearchPack(CtopOauthToken token);

}
